@@ -47,6 +47,7 @@ def skema(self, uge=None, år=None, id=None):
 
     if resp.url != url:
         raise Exception("lectio-cookie udløbet")
+
     soup = BeautifulSoup(resp.text, "html.parser")
 
     if id == None or id[0] == "S" or id[0] == "C":
@@ -59,10 +60,15 @@ def skema(self, uge=None, år=None, id=None):
             else:
                 for gruppe in content:
                     skema["grupper"].append({"navn": gruppe.text, "id": gruppe.find("a").get("href").split("holdelementid=")[1]})
+    elif id[0] == "T":
+        skema["hold"] = self.fåBruger(brugerId=id)["hold"]
+
 
     for modulTid in soup.find_all("div", {"class": "s2module-info"}):
         skema["modulTider"][modulTid.prettify().split("\n")[2].lstrip()] = modulTid.prettify().split("\n")[4].lstrip()
 
+
+
     for dag in soup.find("tr", {"class": "s2dayHeader"}).find_all("td"):
         if dag.text != "":
             skema["ugeDage"].append(dag.text)
